#
# spec file for package libodfgen
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libodfgen-0_1-1 
Name:           libodfgen
Version:        0.1.4
Release:        2.11
Summary:        Library to generate ODF documents from libwpd's and libwpg's api calls
License:        LGPL-2.1+ and MPL-2.0+
Group:          Productivity/Publishing/Word
Url:            http://libwpd.sourceforge.net
Source:         http://downloads.sourceforge.net/project/libwpd/%{name}/%{name}-%{version}/%{name}-%{version}.tar.xz
BuildRequires:  boost-devel
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRequires:  pkgconfig(librevenge-0.0)
BuildRequires:  pkgconfig(librevenge-stream-0.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libodfgen is a general purpose library designed to generate ODF documents
from api calls to libwpd and libwpg libraries.

%package -n %{libname}
Summary:        Library to generate ODF documents from libwpd's and libwpg's api calls
Group:          System/Libraries

%description -n %{libname}
libodfgen is a general purpose library designed to generate ODF documents
from api calls to libwpd and libwpg libraries.

%package devel
Summary:        Library to generate ODF documents from libwpd's and libwpg's api calls
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       libstdc++-devel

%description devel
libodfgen is a general purpose library designed to generate ODF documents
from api calls to libwpd and libwpg libraries.

%package devel-doc
Summary:        Documentation for the libodfgen API
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation for the libodfgen API.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fvisibility-inlines-hidden"
%configure \
	--disable-werror \
	--disable-static \
	--docdir=%{_docdir}/%{name}-devel/html \
	--with-sharedptr=boost

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print

%fdupes -s %{buildroot}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.*
%doc ChangeLog
%doc COPYING.LGPL
%doc COPYING.MPL
%doc NEWS

%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/libodfgen*.pc
%{_includedir}/libodfgen*

%files devel-doc
%defattr(-,root,root,-)
%dir %{_docdir}/%{name}-devel
%doc %{_docdir}/%{name}-devel/html/

%changelog
* Sat Jun 13 2015 tchvatal@suse.com
- Version bump to 0.1.4:
  - drawing interface: do no forget to call startDocument/endDocument when
    writing in the manifest
  - metadata: added handler for 'template' metadata, unknown metadata are
    written in a meta:user-defined elements,
  - defineSheetNumberingStyle: can now define styles for the whole document
    (and not only for the actual sheet)
  - update doxygen configuration file + add a make astyle command
  - Allow writing meta:creation-date metadata element for drawings and
    presentations too.
  - Improve handling of headings. Most importantly, write valid ODF.
  - Write meta:generator metadata element.
  - Add initial support for embedded fonts. It is currently limited to Flat
    ODF output.
* Fri Nov 28 2014 fstrba@suse.com
- Upgrade to version 0.1.2
  * Use text:h element for headings. Any paragraph with
    text:outline-level property is recognized as a heading.
  * Handle layers.
  * Improve handling of styles. Particularly, do not emit
    duplicate styles.
  * Slightly improve documentation.
  * Handle master pages.
  * Do not expect that integer properties are always in inches.
  * Fix misspelled style:paragraph-properties element in
    presentation notes.
  * Only export public symbols on Linux.
  * Fix bogus XML-escaping of metadata values.
  * And many other improvements and fixes.
* Tue Jun  3 2014 fstrba@suse.com
- Upgrade to version 0.1.0
  * Export API symbols on Windows.
  * Fix few minor problems with debug mode.
* Mon May 26 2014 fstrba@suse.com
- Upgrade to version 0.1.0
  * ABI change
  * Remove dependencies on libwpd, libwpg and libetonyek
  * Add dependency on librevenge
* Sat Jan 25 2014 tchvatal@suse.com
- Cleanup with spec-cleaner.
* Sat Jan 18 2014 crrodriguez@opensuse.org
-  build with -fvisibility-inlines-hidden
* Sat Dec 14 2013 fridrich.strba@suse.com
- Version bump to 0.0.4:
  - fix handling of presentation tables
  - fix handling of presentation notes
  - fix handling of presentation comments
* Fri Nov  8 2013 fridrich.strba@suse.com
- Build also the documentation
* Fri Nov  8 2013 tchvatal@suse.com
- Version bump to 0.0.3:
  - handle more table properties
  - more SVG path commands
  - allow to define center of rotation for a textbox
  - make linked text boxes more robust
  - add support for generating presentations (using libetonyek)
  - start on API documentation
* Fri Nov  1 2013 tchvatal@suse.com
- Use verbose build.
* Mon May 27 2013 fridrich.strba@suse.com
- Upstream release 0.0.2
  * Cleanup of build system
  * Source code layout change, so that the public headers
    can be directly included from the tarball
  * Improvements in generation of borders and column separators
* Mon May 13 2013 tchvatal@suse.com
- Drop zlib-devel as it is not really required
* Tue May  7 2013 fridrich.strba@suse.com
- Upstream release 0.0.1
  * Fix android build
  * Fix different warnings
  * Fix different wrong strings
* Mon May  6 2013 tchvatal@suse.com
- Format the spec file.
* Mon May  6 2013 tchvatal@suse.com
- Initial commit of odf generating library. Will be required by
  libreoffice-4.1.
